@@ -72,6 +72,10 @@ class OllamaAI:
                 break
             else:
                 used_api_keys.append(this_api_key)
+            if os.getenv("OLLAMA_HOST") == "https://ollama.com":
+                this_num_predict = int(os.getenv("OLLAMACLOUD_MAX_TOKENS")) if os.getenv("OLLAMACLOUD_MAX_TOKENS") else 65536
+            else:
+                this_num_predict = max_tokens if max_tokens else OllamaAI.DEFAULT_MAX_TOKENS
             try:
                 completion = OllamaAI.getClient(api_endpoint=os.getenv("OLLAMA_HOST"), api_key=this_api_key).chat(
                     keep_alive=model_keep_alive if model_keep_alive else OllamaAI.DEFAULT_KEEP_ALIVE,
@@ -83,7 +87,7 @@ class OllamaAI:
                         temperature=temperature if temperature is not None else OllamaAI.DEFAULT_TEMPERATURE,
                         num_ctx=context_window if context_window is not None else OllamaAI.DEFAULT_CONTEXT_WINDOW,
                         num_batch=batch_size if batch_size is not None else OllamaAI.DEFAULT_BATCH_SIZE,
-                        num_predict=None if os.getenv("OLLAMA_HOST") == "https://ollama.com" else max_tokens if max_tokens else OllamaAI.DEFAULT_MAX_TOKENS,
+                        num_predict=this_num_predict,
                         stop=stop,
                         **kwargs,
                     ),
