@@ -52,8 +52,10 @@ class BibleVerseParser:
     standardAbbreviation = {}
 
     # initialisation
-    def __init__(self, standardisation, noOfLinesPerChunkForParsing=None):
+    def __init__(self, standardisation, noOfLinesPerChunkForParsing=None, language="eng"):
         self.logger = logging.getLogger('uba')
+        # language
+        self.language = language
         # set standard abbreviation, displayed in UniqueBible
         self.updateStandardAbbreviation()
         # noOfLinesPerChunkForParsing
@@ -107,7 +109,7 @@ class BibleVerseParser:
     # update self.standardAbbreviation
     def updateStandardAbbreviation(self):
         self.checkConfig()
-        self.standardAbbreviation = BibleBooks().booksMap.get(config.standardAbbreviation, BibleBooks.abbrev["eng"])
+        self.standardAbbreviation = BibleBooks().booksMap.get(config.standardAbbreviation, BibleBooks.abbrev[self.language])
         self.standardFullBookName = {key: value[1] for key, value in self.standardAbbreviation.items()}
         self.standardAbbreviation = {key: value[0] for key, value in self.standardAbbreviation.items()}
 
@@ -464,7 +466,7 @@ class BibleVerseParser:
         bookList = []
         for book in books:
             if book is not None:
-                bookList.append(BibleBooks.abbrev["eng"][str(book)][0])
+                bookList.append(BibleBooks.abbrev[self.language][str(book)][0])
         return bookList
 
     def extractBookListAsBookNumberList(self, inputString):
